@@ -1,7 +1,7 @@
 package Pod::Weaver::Plugin::Rinci;
 
-our $DATE = '2017-01-14'; # DATE
-our $VERSION = '0.75'; # VERSION
+our $DATE = '2017-01-20'; # DATE
+our $VERSION = '0.76'; # VERSION
 
 use 5.010001;
 use Moose;
@@ -25,7 +25,7 @@ has exclude_files => (
 );
 
 sub _process_module {
-    require Require::Hook::DzilBuild;
+    #require Require::Hook::DzilBuild;
 
     my ($self, $document, $input) = @_;
 
@@ -42,7 +42,9 @@ sub _process_module {
     my $package = $1;
     $package =~ s!/!::!g;
 
-    local @INC = (Require::Hook::DzilBuild->new(zilla => $input->{zilla}), @INC);
+    # can't work for now, Perinci::Access client searches in filesystem
+    #local @INC = (Require::Hook::DzilBuild->new(zilla => $input->{zilla}, debug=>1), @INC);
+    local @INC = ("lib", @INC);
 
     my $url = $package; $url =~ s!::!/!g; $url = "pl:/$url/";
     my $res = $pa->request(meta => $url);
@@ -120,7 +122,7 @@ sub _process_module {
         $self->add_text_to_section($document, $sectcontent, $sectname, \%opts);
     }
     if ($found) {
-        $self->log(["added POD sections from Rinci metadata for module '%s'", $filename]);
+        $self->log(["added POD sections from Rinci metadata for file (module) '%s'", $filename]);
     }
 }
 
@@ -244,7 +246,7 @@ Pod::Weaver::Plugin::Rinci - Insert stuffs to POD from Rinci metadata
 
 =head1 VERSION
 
-This document describes version 0.75 of Pod::Weaver::Plugin::Rinci (from Perl distribution Pod-Weaver-Plugin-Rinci), released on 2017-01-14.
+This document describes version 0.76 of Pod::Weaver::Plugin::Rinci (from Perl distribution Pod-Weaver-Plugin-Rinci), released on 2017-01-20.
 
 =head1 SYNOPSIS
 
